@@ -7,10 +7,11 @@ Bot core
 @copyright Copyright (c) 2004 Riku Lindblad
 @license New-Style BSD
 
-$Id: botcore.py 331 2012-11-13 10:18:18Z riku.lindblad@gmail.com $
-$HeadURL: https://pyfibot.googlecode.com/svn/trunk/pyfibot/botcore.py $
+$Id$
+$HeadURL$
 """
 
+from __future__ import print_function, division
 # twisted imports
 from twisted.words.protocols import irc
 from twisted.internet import reactor, threads
@@ -78,12 +79,13 @@ class CoreCommands(object):
             newchannel, network = args.split('@', 1)
         except ValueError:
             newchannel, network = args, self.network.alias
+
         try:
             bot = self.factory.allBots[network]
         except KeyError:
             self.say(channel, "I am not on that network.")
         else:
-            log.debug("Attempting to join channel %s", channel)
+            log.debug("Attempting to join channel %s on ", (newchannel, network))
             if newchannel in bot.network.channels:
                 self.say(channel, "I am already in %s on %s." % (newchannel, network))
                 log.debug("Already on channel %s" % channel)
@@ -91,7 +93,7 @@ class CoreCommands(object):
             else:
                 if password:
                     bot.join(newchannel, key=password)
-                    log.debug("Joined")
+                    log.debug("Joined with password")
                 else:
                     bot.join(newchannel)
                     log.debug("Joined")
@@ -123,6 +125,7 @@ class CoreCommands(object):
                 self.say(channel, "I am not in %s on %s." % (newchannel, network))
                 self.say(channel, "I am on %s" % bot.network.channels)
             else:
+                log.debug("Parted channel %s" % newchannel)
                 bot.network.channels.remove(newchannel)
                 bot.part(newchannel)
 
@@ -138,7 +141,7 @@ class CoreCommands(object):
     def command_channels(self, user, channel, args):
         """Usage: channels <network> - List channels the bot is on"""
         if not args:
-            self.say(channel, "Please specify a network")
+            self.say(channel, "Please specify a network: %s" % ", ".join(self.factory.allBots.keys()))
             return
 
         self.say(channel, "I am on %s" % self.network.channels)
@@ -167,7 +170,7 @@ class PyFiBot(irc.IRCClient, CoreCommands):
     """PyFiBot"""
 
     nickname = "pyfibot"
-    realname = "http://code.google.com/p/pyfibot/"
+    realname = "https://github.com/lepinkainen/pyfibot"
     password = None
 
     # send 1 msg per second max
@@ -210,6 +213,7 @@ class PyFiBot(irc.IRCClient, CoreCommands):
 
     def signedOn(self):
         """Called when bot has succesfully signed on to server."""
+        log.info("Signed on to network")
         # QuakeNet specific auth and IP-address masking
         # TODO: Alias could be case-sensitive
         if self.network.alias == "quakenet":
@@ -239,8 +243,23 @@ class PyFiBot(irc.IRCClient, CoreCommands):
         reactor.callLater(delay, self.repeatingPing, delay)
         self.ping(self.nickname)
 
+    # TODO: Move the function here completely
+    def getUrl(self, url, nocache=False, params=None, headers=None):
+        return self.factory.getUrl(url, nocache, params, headers)
+
+    # TODO: getNick
+    # TODO: isAdmin
+
     def say(self, channel, message, length=None):
         """Override default say to make replying to private messages easier"""
+
+        # Encode all outgoing messages to UTF-8
+        #message = message.encode("UTF-8")
+
+        # Change nick!user@host -> nick, since all servers don't support full hostmask messaging
+        if "!" and "@" in channel:
+            channel = self.factory.getNick(channel)
+
         # wrap long text into suitable fragments
         msg = self.tw.wrap(message)
         cont = False
